import { b8 as ReportEventRequest$1, a as ReportEventResponse$1, b9 as BulkReportEventRequest$1, B as BulkReportEventResponse$1, be as BulkCancelEventRequest$1, b as BulkCancelEventResponse$1, bg as CancelEventRequest$1, bh as CancelEventResponse$1 } from './automations-v2-activation-activations.universal-BCxUR-p1.mjs';

interface EventInfo {
    /**
     * Event payload, formatted as key:value pairs.
     * Must comply with the payload schema
     * if you provided one when configuring your trigger.
     */
    payload?: Record<string, any> | null;
    /**
     * ID of the related resource in GUID format.
     * @format GUID
     */
    externalEntityId?: string | null;
    /** Idempotency information for the event. */
    idempotency?: Idempotency;
}
interface Idempotency {
    /**
     * A unique identifier for the event.
     * If you send the same idempotency key in multiple report event requests, for the same trigger key and app id,
     * consecutive requests will be ignored after the first one. Note that the idempotency key is kept for a week before it expires.
     * @minLength 1
     * @maxLength 80
     */
    key?: string;
    /**
     * Optional. The time to live (TTL) in milliseconds before the key will expire. Default is a week.
     * @min 1
     */
    ttlInMilliseconds?: string | null;
}
interface ReportEventRequest {
    /**
     * Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Event payload, formatted as key:value pairs.
     * Must comply with the payload schema
     * if you provided one when configuring your trigger.
     *
     * Key names can include only alphanumeric characters or underscores
     * (`A-Z`, `a-z`, `0-9`, `_`).
     * They cannot start with an underscore.
     *
     * Values can be strings, numbers, integers, booleans, or arrays.
     * If a value is an array, the array items must be objects,
     * and nested object properties must be
     * strings, numbers, integers, or booleans only.
     */
    payload?: Record<string, any> | null;
    /**
     * ID of the related resource in GUID format.
     * For example, `fc81a355-3429-50fc-a4c7-def486e828f3`.
     *
     * Required if your app needs to
     * [cancel the event](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/cancel-event)
     * if the automation becomes no longer relevant.
     *
     * Typically, this ID is defined in your system,
     * but you can also use any Wix resource GUID,
     * such as contact ID, member ID, or invoice ID.
     * See
     * [Choose the right `externalEntityId`](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/reporting-and-canceling-events#about-canceling-events)
     * for more information.
     * @format GUID
     */
    externalEntityId?: string | null;
    /** Idempotency information for the event. */
    idempotency?: Idempotency;
}
interface ReportEventResponse {
    /**
     * The activation IDs of triggered ReportEvents.
     * @maxSize 100
     * @format GUID
     */
    activationIds?: string[];
}
interface BulkReportEventRequest {
    /**
     * Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Repeated list of event details for bulk reporting.
     * @minSize 1
     * @maxSize 100
     */
    eventsInfo: EventInfo[];
}
interface BulkReportEventResponse {
    /**
     * Trigger key associated with the event.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** List of results for each item in the bulk report event request. */
    results?: BulkReportEventResult[];
    /** Metadata for the overall bulk action, including success and failure counts. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkReportEventResult {
    /** Metadata for the individual item in the request. */
    itemMetadata?: ItemMetadata;
    /** Event details for the item in the request. */
    eventInfo?: EventInfo;
    /**
     * The activation IDs of triggered ReportEvents.
     * @maxSize 100
     * @format GUID
     */
    activationIds?: string[];
}
interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface BulkCancelEventRequest {
    /**
     * Trigger key whose events you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Repeated list of external_entity_id, representing the related resources' IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    externalEntityIds: string[];
}
interface BulkCancelEventResponse {
    /**
     * Trigger key related to the canceled event.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** List of results for each item in the bulk cancel event request. */
    results?: BulkCancelEventResult[];
    /** Metadata for the overall bulk action, including success and failure counts. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkCancelEventResult {
    /** Metadata of the item, including its ID and success or failure status. */
    itemMetadata?: ItemMetadata;
    /**
     * ID of the related resource in GUID format.
     * @format GUID
     */
    externalEntityId?: string;
}
interface CancelEventRequest {
    /**
     * ID of the related resource in GUID format.
     * For example, `fc81a355-3429-50fc-a4c7-def486e828f3`.
     *
     * Typically, this ID is defined in your system,
     * but you can also use any Wix resource GUID,
     * such as contact ID, member ID, or invoice ID.
     * See
     * [Choose the right `externalEntityId`](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/reporting-and-canceling-events#choose-the-right-externalentityid)
     * for more information.
     * @format GUID
     */
    externalEntityId: string;
    /**
     * Trigger key whose event you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
}
interface CancelEventResponse {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function reportEvent(): __PublicMethodMetaInfo<'POST', {}, ReportEventRequest$1, ReportEventRequest, ReportEventResponse$1, ReportEventResponse>;
declare function bulkReportEvent(): __PublicMethodMetaInfo<'POST', {}, BulkReportEventRequest$1, BulkReportEventRequest, BulkReportEventResponse$1, BulkReportEventResponse>;
declare function bulkCancelEvent(): __PublicMethodMetaInfo<'POST', {}, BulkCancelEventRequest$1, BulkCancelEventRequest, BulkCancelEventResponse$1, BulkCancelEventResponse>;
declare function cancelEvent(): __PublicMethodMetaInfo<'POST', {}, CancelEventRequest$1, CancelEventRequest, CancelEventResponse$1, CancelEventResponse>;

export { type __PublicMethodMetaInfo, bulkCancelEvent, bulkReportEvent, cancelEvent, reportEvent };
